==> skirental_frontend_api-2.2.1.gem: app/controllers/skirental_frontend_api/shop_data_controller.rb <==
# encoding: utf-8
require_dependency "skirental_frontend_api/application_controller"

module SkirentalFrontendApi
    class ShopDataController < ApplicationController
        before_action :set_shop_params

        def show
            @shop_datum = SkirentalApi::Client.shop_datum(@shop_id, @shop_lang)
        end

        def product_categories
            @product_categories = SkirentalApi::Client.categories(@shop_id, @shop_lang)
        end

        def packages
            @product_packages = SkirentalApi::Client.packages(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @product_packages
        end

        def products
            @products = SkirentalApi::Client.products(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @products
        end

        def all_categories_with_packages_and_products
            @everything = SkirentalApi::Client.all_categories_with_packages_and_products(@shop_id, @start_date, @duration, @shop_lang)
            render :json => @everything
        end

        def metrics
            @metrics = SkirentalApi::Client.metrics(@shop_id, @metric_type, @shop_lang)
            render :json => @metrics
        end

        def availability
            @availability = SkirentalApi::Client.availability(@shop_lic, @date, @product_id)
            render :json => @availability
        end

        private

        def set_shop_params
            @shop_id             = shop_datum_params[:shop_id]
            @shop_lang           = shop_datum_params[:lang]
            @product_category_id = shop_datum_params[:product_category_id]
            @start_date          = shop_datum_params[:start]
            @duration            = shop_datum_params[:duration]
            @customer_group_id   = shop_datum_params[:customer_group_id]
            @metric_type         = shop_datum_params[:metric_type]
            @shop_lic            = shop_datum_params[:shop_lic]
            @date                = shop_datum_params[:date]
            @product_id          = shop_datum_params[:product_id]
        end

        # Only allow a trusted parameter "white list" through.
        def shop_datum_params
            params.permit(:shop_id, :lang, :product_category_id, :start, :duration, :customer_group_id,
                          :metric_type, :product_id, :shop_lic, :date, :product_id, shop_datum: {})
        end
    end
end

==> skirental_frontend_api-3.0.0.pre1.gem: app/controllers/skirental_frontend_api/shop_data_controller.rb <==
# encoding: utf-8
require_dependency "skirental_frontend_api/application_controller"

module SkirentalFrontendApi
    class ShopDataController < ApplicationController
        before_action :set_shop_params

        def show
            @shop_datum = SkirentalApi::Client.shop_datum(@shop_id, @shop_lang)
        end

        def product_categories
            @product_categories = SkirentalApi::Client.categories(@shop_id, @shop_lang)
        end

        def packages
            @product_packages = SkirentalApi::Client.packages(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @product_packages
        end

        def products
            @products = SkirentalApi::Client.products(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @products
        end

        def all_categories_with_packages_and_products
            @everything = SkirentalApi::Client.all_categories_with_packages_and_products(@shop_id, @start_date, @duration, @shop_lang)
            render :json => @everything
        end

        def metrics
            @metrics = SkirentalApi::Client.metrics(@shop_id, @metric_type, @shop_lang)
            render :json => @metrics
        end

        def availability
            @availability = SkirentalApi::Client.availability(@shop_lic, @date, @product_id)
            render :json => @availability
        end

        def availability_variants
            @availability_variants = SkirentalApi::Client.availability_variants(@shop_id, @product_id, @from_date, @until_date)
            render :json => @availability_variants
        end

        def availability_variants_list
            @availability_variants_list = SkirentalApi::Client.availability_variants_list(@shop_id, @product_id, @from_date, @until_date, shop_datum_params[:prop1], shop_datum_params[:prop2])
            render :json => @availability_variants_list
        end

        private

        def set_shop_params
            @shop_id             = shop_datum_params[:shop_id]
            @shop_lang           = shop_datum_params[:lang]
            @product_category_id = shop_datum_params[:product_category_id]
            @start_date          = shop_datum_params[:start]
            @duration            = shop_datum_params[:duration]
            @customer_group_id   = shop_datum_params[:customer_group_id]
            @metric_type         = shop_datum_params[:metric_type]
            @shop_lic            = shop_datum_params[:shop_lic]
            @date                = shop_datum_params[:date]
            @from_date           = shop_datum_params[:from_date]
            @until_date          = shop_datum_params[:until_date]
            @product_id          = shop_datum_params[:product_id]
        end

        # Only allow a trusted parameter "white list" through.
        def shop_datum_params
            params.permit(:shop_id, :lang, :product_category_id, :start, :duration, :customer_group_id,
                          :metric_type, :product_id, :shop_lic, :date, :from_date, :until_date, :prop1, :prop2, :product_id, shop_datum: {})
        end
    end
end
